@@ -173,7 +173,7 @@ class DepthAIPipeline:
             frame = frame.transpose(1, 2, 0)
             frame = frame.astype(np.uint8)
             frame = np.ascontiguousarray(frame)
-            frame_raw = frame
+            frame_raw = np.array(frame)
 
 
         if frame is not None:
